==> haskell-missingh-1.3.0.1-4-armv7h.pkg.tar.xz: usr/share/haskell/haskell-missingh/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: MissingH
version: 1.3.0.1
id: MissingH-1.3.0.1-850f436f21e47070372933951418ea9c
key: Missi_0Dce8ROm10WBZH8OmzytED
license: BSD3
copyright: Copyright (c) 2004-2014 John Goerzen
maintainer: John Goerzen <jgoerzen@complete.org>
stability: Beta
homepage: http://software.complete.org/missingh
synopsis: Large utility library
description:
    MissingH is a library of all sorts of utility functions for
    Haskell programmers.  It is written in pure Haskell and thus should
    be extremely portable and easy to use.
category: Unclassified
author: John Goerzen
exposed: True
exposed-modules:
    Data.String.Utils System.IO.Utils System.IO.Binary Data.List.Utils
    System.Daemon Text.ParserCombinators.Parsec.Utils
    Network.Email.Mailbox Control.Concurrent.Thread.Utils
    Network.Email.Sendmail Data.CSV System.Cmd.Utils Data.BinPacking
    Data.Progress.Tracker Data.Progress.Meter Data.Quantity
    Data.Map.Utils System.Path System.Path.NameManip
    System.Path.WildMatch System.Path.Glob System.Time.Utils
    System.Time.ParseDate Network.Utils Network.SocketServer
    Data.Either.Utils Data.Maybe.Utils Data.Tuple.Utils Data.Bits.Utils
    Data.Hash.CRC32.Posix Data.Hash.CRC32.GZip Data.Hash.MD5
    Data.Hash.MD5.Zord64_HARD Data.Compression.Inflate
    System.FileArchive.GZip System.IO.HVFS System.IO.HVFS.Combinators
    System.IO.HVFS.InstanceHelpers System.IO.HVFS.Utils System.IO.HVIO
    System.IO.StatCompat System.IO.WindowsCompat System.IO.PlafCompat
    System.Posix.Consts System.Debian System.Debian.ControlParser
    Data.MIME.Types System.Console.GetOpt.Utils
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/MissingH-1.3.0.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/MissingH-1.3.0.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/MissingH-1.3.0.1
hs-libraries: HSMissingH-1.3.0.1-0Dce8ROm10WBZH8OmzytED
depends:
    HUnit-1.3.1.1-21d4c913eac2236e948873e3db41c801
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    hslogger-1.2.9-81a50dffe37950dc2d1edc0d348f3eed
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
    old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
    old-time-1.1.0.3-91625432bd7c61d043f9b743fb82dcf7
    parsec-3.1.9-e73195cf6af19ee9d1587f67fa792c42
    process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
    random-1.1-41a0a7ecd483c665a5c3a093a5be2968
    regex-compat-0.95.1-89e892301603bb8833ca6f1a349f5b4f
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
    unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
haddock-interfaces: /usr/share/doc/haskell-missingh/html/MissingH.haddock
haddock-html: /usr/share/doc/haskell-missingh/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-missingh-1.3.0.1-5-armv7h.pkg.tar.xz: usr/share/haskell/haskell-missingh/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: MissingH
version: 1.3.0.1
id: MissingH-1.3.0.1-af8516ecf9f3f6f260319a04c2ae8afa
key: Missi_Ib1zDeoXo62AcZUCIuxqeF
license: BSD3
copyright: Copyright (c) 2004-2014 John Goerzen
maintainer: John Goerzen <jgoerzen@complete.org>
stability: Beta
homepage: http://software.complete.org/missingh
synopsis: Large utility library
description:
    MissingH is a library of all sorts of utility functions for
    Haskell programmers.  It is written in pure Haskell and thus should
    be extremely portable and easy to use.
category: Unclassified
author: John Goerzen
exposed: True
exposed-modules:
    Data.String.Utils System.IO.Utils System.IO.Binary Data.List.Utils
    System.Daemon Text.ParserCombinators.Parsec.Utils
    Network.Email.Mailbox Control.Concurrent.Thread.Utils
    Network.Email.Sendmail Data.CSV System.Cmd.Utils Data.BinPacking
    Data.Progress.Tracker Data.Progress.Meter Data.Quantity
    Data.Map.Utils System.Path System.Path.NameManip
    System.Path.WildMatch System.Path.Glob System.Time.Utils
    System.Time.ParseDate Network.Utils Network.SocketServer
    Data.Either.Utils Data.Maybe.Utils Data.Tuple.Utils Data.Bits.Utils
    Data.Hash.CRC32.Posix Data.Hash.CRC32.GZip Data.Hash.MD5
    Data.Hash.MD5.Zord64_HARD Data.Compression.Inflate
    System.FileArchive.GZip System.IO.HVFS System.IO.HVFS.Combinators
    System.IO.HVFS.InstanceHelpers System.IO.HVFS.Utils System.IO.HVIO
    System.IO.StatCompat System.IO.WindowsCompat System.IO.PlafCompat
    System.Posix.Consts System.Debian System.Debian.ControlParser
    Data.MIME.Types System.Console.GetOpt.Utils
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/MissingH-1.3.0.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/MissingH-1.3.0.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/MissingH-1.3.0.1
hs-libraries: HSMissingH-1.3.0.1-Ib1zDeoXo62AcZUCIuxqeF
depends:
    HUnit-1.3.1.1-21d4c913eac2236e948873e3db41c801
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    hslogger-1.2.9-81a50dffe37950dc2d1edc0d348f3eed
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
    old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
    old-time-1.1.0.3-91625432bd7c61d043f9b743fb82dcf7
    parsec-3.1.9-3365ddffd9ca11d2f0b377e002b54baf
    process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
    random-1.1-41a0a7ecd483c665a5c3a093a5be2968
    regex-compat-0.95.1-89e892301603bb8833ca6f1a349f5b4f
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
    unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
haddock-interfaces: /usr/share/doc/haskell-missingh/html/MissingH.haddock
haddock-html: /usr/share/doc/haskell-missingh/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
